@@ -18,10 +18,10 @@ use zeroize::Zeroize;
 use crate::error::Error;
 
 /// Trait represents a public key.
-pub trait PublicKey: Debug + Copy + PartialEq + Zeroize {}
+pub trait PublicKey: Debug + Clone + Copy + PartialEq + Zeroize {}
 
 /// Trait represents a secret key.
-pub trait SecretKey: Zeroize + Debug {
+pub trait SecretKey: Clone + Zeroize + Debug {
     type PK: PublicKey;
 
     /// Generate an "unbiased" `SecretKey`;
@@ -41,7 +41,7 @@ pub trait SecretKey: Zeroize + Debug {
 pub trait SharedSecretKey {}
 
 /// Trait represents a keypair.
-pub trait KeyPair: Zeroize {
+pub trait KeyPair: Clone + Zeroize {
     type SK: SecretKey;
 
     /// Generate an "unbiased" `KeyPair`.
@@ -97,3 +97,16 @@ pub trait WithPhrase {
         Self: Sized,
         R: RngCore + CryptoRng;
 }
+
+/// Perform a blinding operation on keys.
+pub trait Blind {
+    type E: Error;
+
+    /// Perform a blinding operation on the key with the given blinding factor.
+    fn blind(&mut self, blinding_factor: &[u8]) -> Result<(), Self::E>;
+
+    /// Perform a blinding operation on the key with the given blinding factor.
+    fn to_blind(&self, blinding_factor: &[u8]) -> Result<Self, Self::E>
+    where
+        Self: Sized;
+}
